Index: main/waeup.custom/trunk/src/waeup/custom/applicants/utils.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/applicants/utils.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/applicants/utils.py	(revision 7822)
@@ -20,5 +20,5 @@
 
 import grok
-from waeup.sirp.applicants.utils import ApplicantsUtils
+from waeup.kofa.applicants.utils import ApplicantsUtils
 
 class ApplicantsUtils(ApplicantsUtils):
Index: main/waeup.custom/trunk/src/waeup/custom/browser/pages.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/browser/pages.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/browser/pages.py	(revision 7822)
@@ -17,5 +17,5 @@
 ##
 import grok
-from waeup.sirp.browser.pages import (
+from waeup.kofa.browser.pages import (
     SessionConfigurationAddFormPage, SessionConfigurationManageFormPage)
 from waeup.custom.interfaces import (
Index: main/waeup.custom/trunk/src/waeup/custom/browser/resources.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/browser/resources.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/browser/resources.py	(revision 7822)
@@ -17,5 +17,5 @@
 ##
 import grok
-from waeup.sirp.browser.resources import (
+from waeup.kofa.browser.resources import (
     Library, ResourceInclusion, waeup_base_css,
     )
Index: main/waeup.custom/trunk/src/waeup/custom/browser/tests.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/browser/tests.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/browser/tests.py	(revision 7822)
@@ -20,7 +20,7 @@
 from zope.testbrowser.testing import Browser
 from zope.component.hooks import setSite, clearSite
-from waeup.sirp.testing import FunctionalTestCase
+from waeup.kofa.testing import FunctionalTestCase
 from waeup.custom.testing import FunctionalLayer
-from waeup.sirp.app import University
+from waeup.kofa.app import University
 
 class CustomPackageBrowserTests(FunctionalTestCase):
Index: main/waeup.custom/trunk/src/waeup/custom/configuration.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/configuration.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/configuration.py	(revision 7822)
@@ -21,6 +21,6 @@
 import grok
 from zope.interface import implementedBy
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.configuration import (
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.configuration import (
     SessionConfigurationFactory, SessionConfiguration)
 from waeup.custom.interfaces import (
Index: main/waeup.custom/trunk/src/waeup/custom/ftesting.zcml
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/ftesting.zcml	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/ftesting.zcml	(revision 7822)
@@ -1,5 +1,5 @@
 <configure
    xmlns="http://namespaces.zope.org/zope"
-   xmlns:sirp="http://namespaces.waeup.org/sirp"
+   xmlns:kofa="http://namespaces.waeup.org/kofa"
    i18n_domain="waeup.custom"
    package="waeup.custom"
@@ -11,5 +11,5 @@
 
   <!-- Where should the datacenter reside by default? -->
-  <sirp:datacenter
+  <kofa:datacenter
       path="../../../parts/test/datacenter" />
 
Index: main/waeup.custom/trunk/src/waeup/custom/interfaces.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/interfaces.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/interfaces.py	(revision 7822)
@@ -19,5 +19,5 @@
 import zope.i18nmessageid
 from zope import schema
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     ISessionConfiguration, academic_sessions_vocab)
 
Index: main/waeup.custom/trunk/src/waeup/custom/locales/de/LC_MESSAGES/waeup.custom.po
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/locales/de/LC_MESSAGES/waeup.custom.po	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/locales/de/LC_MESSAGES/waeup.custom.po	(revision 7822)
@@ -14,7 +14,7 @@
 msgid ""
 msgstr ""
-"Project-Id-Version: WAeUP.SIRP\n"
+"Project-Id-Version: WAeUP.Kofa\n"
 "POT-Creation-Date: Thu Feb 23 18:36:34 2012\n"
-"PO-Revision-Date: 2012-02-23 18:43+0100\n"
+"PO-Revision-Date: 2012-03-09 08:17+0100\n"
 "Last-Translator: Henrik Bettermann <henrik@waeup.org>\n"
 "Language-Team: WAeUP Germany <henrik@waeup.org>\n"
Index: main/waeup.custom/trunk/src/waeup/custom/locales/fr/LC_MESSAGES/waeup.custom.po
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/locales/fr/LC_MESSAGES/waeup.custom.po	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/locales/fr/LC_MESSAGES/waeup.custom.po	(revision 7822)
@@ -14,7 +14,7 @@
 msgid ""
 msgstr ""
-"Project-Id-Version: WAeUP.SIRP\n"
+"Project-Id-Version: WAeUP.Kofa\n"
 "POT-Creation-Date: Thu Feb 23 18:36:34 2012\n"
-"PO-Revision-Date: 2012-02-23 21:27+0100\n"
+"PO-Revision-Date: 2012-03-09 08:17+0100\n"
 "Last-Translator: Henrik Bettermann <henrik@waeup.org>\n"
 "Language-Team: WAeUP Niger <isouaba@waeup.org>\n"
Index: main/waeup.custom/trunk/src/waeup/custom/locales/ha/LC_MESSAGES/waeup.custom.po
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/locales/ha/LC_MESSAGES/waeup.custom.po	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/locales/ha/LC_MESSAGES/waeup.custom.po	(revision 7822)
@@ -14,7 +14,7 @@
 msgid ""
 msgstr ""
-"Project-Id-Version: WAeUP.SIRP\n"
+"Project-Id-Version: WAeUP.Kofa\n"
 "POT-Creation-Date: Thu Feb 23 18:36:34 2012\n"
-"PO-Revision-Date: 2012-02-23 21:27+0100\n"
+"PO-Revision-Date: 2012-03-09 08:16+0100\n"
 "Last-Translator: Henrik Bettermann <henrik@waeup.org>\n"
 "Language-Team: WAeUP Niger <isouaba@waeup.org>\n"
Index: main/waeup.custom/trunk/src/waeup/custom/locales/yo/LC_MESSAGES/waeup.custom.po
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/locales/yo/LC_MESSAGES/waeup.custom.po	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/locales/yo/LC_MESSAGES/waeup.custom.po	(revision 7822)
@@ -14,7 +14,7 @@
 msgid ""
 msgstr ""
-"Project-Id-Version: WAeUP.SIRP\n"
+"Project-Id-Version: WAeUP.Kofa\n"
 "POT-Creation-Date: Thu Feb 23 18:36:34 2012\n"
-"PO-Revision-Date: 2012-02-23 21:27+0100\n"
+"PO-Revision-Date: 2012-03-09 08:17+0100\n"
 "Last-Translator: Henrik Bettermann <henrik@waeup.org>\n"
 "Language-Team: WAeUP Nigeria <isouaba@waeup.org>\n"
Index: main/waeup.custom/trunk/src/waeup/custom/mail.zcml
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/mail.zcml	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/mail.zcml	(revision 7822)
@@ -29,5 +29,5 @@
    background thread and sends mail independently from requests.
 
-   By default in SIRP we have a fake mailer activated, that does not
+   By default in Kofa we have a fake mailer activated, that does not
    send real mail to the outside world.
   -->
Index: main/waeup.custom/trunk/src/waeup/custom/students/batching.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/batching.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/batching.py	(revision 7822)
@@ -27,5 +27,5 @@
     IStudent, 
     )
-from waeup.sirp.students.batching import StudentProcessor
+from waeup.kofa.students.batching import StudentProcessor
 
 class StudentProcessor(StudentProcessor):
Index: main/waeup.custom/trunk/src/waeup/custom/students/browser.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/browser.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/browser.py	(revision 7822)
@@ -18,5 +18,5 @@
 import grok
 from zope.formlib.textwidgets import BytesDisplayWidget
-from waeup.sirp.widgets.datewidget import (
+from waeup.kofa.widgets.datewidget import (
     FriendlyDateWidget, FriendlyDateDisplayWidget
     )
@@ -24,5 +24,5 @@
     IStudent, IStudentPersonal, IStudentClearance, IStudentClearanceEdit
     )
-from waeup.sirp.students.browser import (
+from waeup.kofa.students.browser import (
     StudentPersonalDisplayFormPage, StudentPersonalManageFormPage,
     StudentClearanceManageFormPage, StudentClearanceEditFormPage,
Index: main/waeup.custom/trunk/src/waeup/custom/students/interfaces.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/interfaces.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/interfaces.py	(revision 7822)
@@ -17,10 +17,10 @@
 ##
 from zope import schema
-from waeup.sirp.schema import TextLineChoice
-from waeup.sirp.interfaces import SimpleSIRPVocabulary
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.schema import TextLineChoice
+from waeup.kofa.interfaces import SimpleKofaVocabulary
+from waeup.kofa.students.interfaces import (
     IStudentBase,IStudentClearance,IStudentPersonal,IStudentNavigation,
     )
-from waeup.sirp.students.vocabularies import (
+from waeup.kofa.students.vocabularies import (
     lgas_vocab, nats_vocab, contextual_reg_num_source)
 
@@ -46,5 +46,5 @@
         default = 'unmarried',
         required = False,
-        vocabulary = SimpleSIRPVocabulary(
+        vocabulary = SimpleKofaVocabulary(
             ('Unmarried', 'unmarried'),
             ('Married', 'married'),)
Index: main/waeup.custom/trunk/src/waeup/custom/students/student.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/student.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/student.py	(revision 7822)
@@ -21,6 +21,6 @@
 import grok
 from zope.interface import implementedBy
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.students.student import Student, StudentFactory
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.students.student import Student, StudentFactory
 from waeup.custom.students.interfaces import (
     IStudent, IStudentNavigation,
Index: main/waeup.custom/trunk/src/waeup/custom/students/tests.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/tests.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/tests.py	(revision 7822)
@@ -20,8 +20,8 @@
 import tempfile
 from zope.component.hooks import setSite, clearSite
-from waeup.sirp.app import University
-from waeup.sirp.students.tests.test_browser import StudentsFullSetup
-from waeup.sirp.testing import FunctionalTestCase
-from waeup.sirp.students.batching import StudentProcessor as StudentProcessorBase
+from waeup.kofa.app import University
+from waeup.kofa.students.tests.test_browser import StudentsFullSetup
+from waeup.kofa.testing import FunctionalTestCase
+from waeup.kofa.students.batching import StudentProcessor as StudentProcessorBase
 from waeup.custom.students.batching import StudentProcessor
 from waeup.custom.testing import FunctionalLayer
Index: main/waeup.custom/trunk/src/waeup/custom/students/utils.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/students/utils.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/students/utils.py	(revision 7822)
@@ -17,7 +17,7 @@
 ##
 import grok
-from waeup.sirp.students.workflow import CLEARED, RETURNING
-from waeup.sirp.students.utils import StudentsUtils
-from waeup.sirp.students.interfaces import IStudentsUtils
+from waeup.kofa.students.workflow import CLEARED, RETURNING
+from waeup.kofa.students.utils import StudentsUtils
+from waeup.kofa.students.interfaces import IStudentsUtils
 
 def get_school_fee(student, surcharge):
Index: main/waeup.custom/trunk/src/waeup/custom/tests/test_configuration.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/tests/test_configuration.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/tests/test_configuration.py	(revision 7822)
@@ -20,8 +20,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import verify
-from waeup.sirp.testing import FunctionalTestCase
-from waeup.sirp.configuration import ConfigurationContainer
-from waeup.sirp.interfaces import IConfigurationContainer
-from waeup.sirp.tests.test_configuration import (
+from waeup.kofa.testing import FunctionalTestCase
+from waeup.kofa.configuration import ConfigurationContainer
+from waeup.kofa.interfaces import IConfigurationContainer
+from waeup.kofa.tests.test_configuration import (
     ConfigurationTest, SessionConfigurationFactoryTest)
 from waeup.custom.configuration import (
Index: main/waeup.custom/trunk/src/waeup/custom/tests/test_datacenter.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/tests/test_datacenter.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/tests/test_datacenter.py	(revision 7822)
@@ -16,6 +16,6 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-from waeup.sirp.datacenter import DataCenter
-from waeup.sirp.testing import FunctionalTestCase
+from waeup.kofa.datacenter import DataCenter
+from waeup.kofa.testing import FunctionalTestCase
 from waeup.custom.testing import FunctionalLayer
 
Index: main/waeup.custom/trunk/src/waeup/custom/tests/test_smtp.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/tests/test_smtp.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/tests/test_smtp.py	(revision 7822)
@@ -27,10 +27,10 @@
 from zope.component.hooks import setSite
 from zope.sendmail.interfaces import IMailDelivery
-from waeup.sirp.app import University
-from waeup.sirp.interfaces import IMailService
-from waeup.sirp.smtp import (
+from waeup.kofa.app import University
+from waeup.kofa.interfaces import IMailService
+from waeup.kofa.smtp import (
     encode_header_item, encode_address, encode_body, FakeSMTPDelivery,
     send_mail)
-from waeup.sirp.testing import FunctionalTestCase
+from waeup.kofa.testing import FunctionalTestCase
 from waeup.custom.testing import FunctionalLayer
 
@@ -103,5 +103,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP SIRP',
+            'Test Mail from WAeUP Kofa',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
@@ -120,5 +120,5 @@
             'test program', 'no-reply@waeup.org',
             'test mail receiver', EXTERNAL_MAIL_RECEIVER,
-            'Test Mail from WAeUP SIRP',
+            'Test Mail from WAeUP Kofa',
             'Hi from test mailer!\n\nRegards,\nTest Programme\n'
             )
Index: main/waeup.custom/trunk/src/waeup/custom/utils/tests.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/utils/tests.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/utils/tests.py	(revision 7822)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-from waeup.sirp.testing import FunctionalTestCase
+from waeup.kofa.testing import FunctionalTestCase
 from waeup.custom.testing import FunctionalLayer
 
Index: main/waeup.custom/trunk/src/waeup/custom/browser/theming.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/browser/theming.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/browser/theming.py	(revision 7822)
@@ -17,5 +17,5 @@
 ##
 import grok
-from waeup.sirp.browser.interfaces import ITheme
+from waeup.kofa.browser.interfaces import ITheme
 from waeup.custom.browser.resources import custom_theme_1
 
@@ -23,5 +23,5 @@
 
 class CustomTheme1(grok.GlobalUtility):
     """A custom theme based on the SIRP base theme.
     """
     grok.implements(ITheme)
@@ -23,5 +23,5 @@
 
 class CustomTheme1(grok.GlobalUtility):
-    """A custom theme based on the SIRP base theme.
+    """A custom theme based on the Kofa base theme.
     """
     grok.implements(ITheme)
Index: main/waeup.custom/trunk/src/waeup/custom/utils/utils.py
===================================================================
--- main/waeup.custom/trunk/src/waeup/custom/utils/utils.py	(revision 7699)
+++ main/waeup.custom/trunk/src/waeup/custom/utils/utils.py	(revision 7822)
@@ -16,11 +16,11 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Customize general helper utilities for SIRP.
 """
 import os
-from waeup.sirp.utils.utils import SIRPUtils
+from waeup.kofa.utils.utils import KofaUtils
 
 
-class SIRPUtils(SIRPUtils):
+class KofaUtils(KofaUtils):
     """A collection of methods subject to customization.
     """
@@ -16,11 +16,11 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Customize general helper utilities for SIRP.
+"""Customize general helper utilities for Kofa.
 """
 import os
